# Miscellanous Scripts

This directory contains various applications of the giftwrap package. 
The scripts are not part of the main package, but may be useful for various tasks.

## Scripts
* `collect_saturations.py`: Compiles saturation data from multiple files data sets into a single file.